# coding: utf-8

"""
    Spotii Notification API

    API for notification things  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import notification_client
from notification.body import Body  # noqa: E501
from notification_client.rest import ApiException


class TestBody(unittest.TestCase):
    """Body unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testBody(self):
        """Test Body"""
        # FIXME: construct object with mandatory attributes with example values
        # model = notification_client.models.body.Body()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Spotii Notification API

    API for notification things  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import notification_client
from notification.default_api import DefaultApi  # noqa: E501
from notification_client.rest import ApiException


class TestDefaultApi(unittest.TestCase):
    """DefaultApi unit test stubs"""

    def setUp(self):
        self.api = notification.default_api.DefaultApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_message(self):
        """Test case for create_message

        """
        pass

    def test_create_message_0(self):
        """Test case for create_message_0

        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Spotii Notification API

    API for notification things  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class Body1(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'subject': 'str',
        'text': 'str',
        'recipient_email': 'str'
    }

    attribute_map = {
        'subject': 'subject',
        'text': 'text',
        'recipient_email': 'recipient_email'
    }

    def __init__(self, subject=None, text=None, recipient_email=None):  # noqa: E501
        """Body1 - a model defined in Swagger"""  # noqa: E501
        self._subject = None
        self._text = None
        self._recipient_email = None
        self.discriminator = None
        self.subject = subject
        self.text = text
        self.recipient_email = recipient_email

    @property
    def subject(self):
        """Gets the subject of this Body1.  # noqa: E501


        :return: The subject of this Body1.  # noqa: E501
        :rtype: str
        """
        return self._subject

    @subject.setter
    def subject(self, subject):
        """Sets the subject of this Body1.


        :param subject: The subject of this Body1.  # noqa: E501
        :type: str
        """
        if subject is None:
            raise ValueError("Invalid value for `subject`, must not be `None`")  # noqa: E501

        self._subject = subject

    @property
    def text(self):
        """Gets the text of this Body1.  # noqa: E501


        :return: The text of this Body1.  # noqa: E501
        :rtype: str
        """
        return self._text

    @text.setter
    def text(self, text):
        """Sets the text of this Body1.


        :param text: The text of this Body1.  # noqa: E501
        :type: str
        """
        if text is None:
            raise ValueError("Invalid value for `text`, must not be `None`")  # noqa: E501

        self._text = text

    @property
    def recipient_email(self):
        """Gets the recipient_email of this Body1.  # noqa: E501


        :return: The recipient_email of this Body1.  # noqa: E501
        :rtype: str
        """
        return self._recipient_email

    @recipient_email.setter
    def recipient_email(self, recipient_email):
        """Sets the recipient_email of this Body1.


        :param recipient_email: The recipient_email of this Body1.  # noqa: E501
        :type: str
        """
        if recipient_email is None:
            raise ValueError("Invalid value for `recipient_email`, must not be `None`")  # noqa: E501

        self._recipient_email = recipient_email

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Body1, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Body1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
